@@ -408,7 +408,7 @@ gnome_font_refresh_font_dir (GnomeFontClass *class, char *dirname)
 	      debugmsg (_("checking file %s\n"), dir_ent->d_name);
 	      fn = g_malloc (strlen (dirname) + strlen (dir_ent->d_name) + 2);
 	      sprintf (fn, _("%s/%s"), dirname, dir_ent->d_name);
-	      afm_f = fopen (fn, "rb");
+	      afm_f = fopen (fn, "r");
 	      if (afm_f != NULL)
 		{
 		  status = parseFile (afm_f, &fi, P_G);
@@ -711,7 +711,7 @@ gnome_font_load_afm (GnomeFontMap *fontmap_entry)
   FILE *afm_f;
   int status;
 
-  afm_f = fopen (fontmap_entry->afm_fn, "rb");
+  afm_f = fopen (fontmap_entry->afm_fn, "r");
   if (afm_f != NULL)
     {
       status = parseFile (afm_f, &fi, P_M | P_P);
@@ -973,8 +973,12 @@ gnome_font_unsized_closest (const char *family_name,
 
   if (best == -1)
     {
-      g_warning (_("gnome_font_new_closest: font family %s not found\n"),
+#if 0
+      /* Why print anything here?  An application that does fancy stuff
+	 with fonts surely knows how to deal with an error like this.  */
+      g_warning (_("gnome_font_unsized_closest: font family %s not found\n"),
 		 family_name);
+#endif
       return NULL;
     }
 
@@ -1015,8 +1019,12 @@ gnome_font_new_closest (const char *family_name,
 
   if (best == -1)
     {
+#if 0
+      /* Why print anything here?  An application that does fancy stuff
+	 with fonts surely knows how to deal with an error like this.  */
       g_warning (_("gnome_font_new_closest: font family %s not found\n"),
 		 family_name);
+#endif
       return NULL;
     }
 
@@ -1190,7 +1198,7 @@ gnome_font_unsized_get_pfa (GnomeFontUnsized *font)
       pfb_fn = subst->pfb_fn;
     }
 #endif
-  f = fopen (pfb_fn, "rb");
+  f = fopen (pfb_fn, "r");
   if (f == NULL)
     {
       g_warning (_("Couldn't open font file %s\n"), pfb_fn);
@@ -1249,9 +1257,17 @@ gnome_font_unsized_get_width (GnomeFontUnsized *font, int ch)
   return font->widths[ch];
 }
 
-/* This works with the standard Adobe encoding and without kerning or
-   ligatures. When the text libs get written, this function will be
-   deprecated. */
+/**
+ * gnome_font_get_width_string:
+ * @font: the GnomeFont to operate on
+ * @s: the string to measure
+ *
+ * This works with the standard Adobe encoding and without kerning or
+ * ligatures. When the text libs get written, this function will be
+ * deprecated.
+ *
+ * Returns: the length of the string @s using the @font.
+ */
 double
 gnome_font_get_width_string (GnomeFont *font, const char *s)
 {
@@ -1266,9 +1282,19 @@ gnome_font_get_width_string (GnomeFont *font, const char *s)
   return width * font->scale;
 }
 
-/* This works with the standard Adobe encoding and without kerning or
-   ligatures. When the text libs get written, this function will be
-   deprecated. */
+/**
+ * gnome_font_get_width_string_n:
+ * @font: the GnomeFont to operate on
+ * @s: the string to measure
+ * @n: number of characters to measure
+ *
+ * This works with the standard Adobe encoding and without kerning or
+ * ligatures. When the text libs get written, this function will be
+ * deprecated.
+ *
+ * Returns: the length of the @n characters of the string @s using
+ * the @font.
+ */
 double
 gnome_font_get_width_string_n (GnomeFont *font, const char *s, int n)
 {
@@ -1276,7 +1302,7 @@ gnome_font_get_width_string_n (GnomeFont *font, const char *s, int n)
   int const * const widths = font->fontmap_entry->widths;
   double width = 0.0;
   while (--n >= 0)
-      width += widths[*(us++) ];
+    width += widths[*(us++) ];
   return width * font->scale;
 }
 
@@ -1331,9 +1357,9 @@ gnome_font_list (GnomeFontClass *class)
   list = NULL;
 
   for (i = 0; i < class->n_fonts; i++)
-   list = g_list_append (list, fontmap[i].font_name);
+   list = g_list_prepend (list, fontmap[i].font_name);
 
-  return list;
+  return g_list_reverse (list);
 }
 
 void
@@ -1879,6 +1905,11 @@ static GnomeDisplayFont *create_display_font (const char *family,
 
   g_free (xfn);
 
+  /* FIXME: we are unref-ing "closest" which makes this undefined.
+     But no-one is actually using it.  */
+  wpdf->unsized_font = NULL;
+  gtk_object_unref (GTK_OBJECT (closest));
+
   return wpdf;
 }
 
