@@ -76,7 +76,7 @@ gnome_print_meta_finalize (GtkObject *object)
 }
 
 static void
-encode_block (GnomePrintMeta *meta, int size, void *data)
+encode_block (GnomePrintMeta *meta, int size, void const *data)
 {
 	int bytes_left;
 
@@ -269,7 +269,7 @@ meta_setfont (GnomePrintContext *pc, GnomeFont *font)
 
 
 static int
-meta_show (GnomePrintContext *pc, char *text)
+meta_show (GnomePrintContext *pc, char const *text)
 {
 	int len = strlen (text);
 	
