@@ -67,6 +67,8 @@ struct _GnomePrintPreviewPrivate {
 	GArray *pages;
 
 	GHashTable *font_hash;
+
+	GnomeCanvasItem *auto_hide_page_on_stroke;
 };
 
 #define gc(o) ((GraphicContext *)((o)->context_list->data))
@@ -151,6 +153,22 @@ dump_gc (GnomePrintPreview *pp)
 	}
 }
 
+/*
+ * This just enables us to avoid doing a control of the page/display
+ * when the job is finished (for the sample applications).
+ *
+ * ie, we are delaying showpage's item_hide on the page until the first
+ * output command for the next page.
+ */
+static void
+lazy_showpage_check (GnomePrintPreviewPrivate *priv)
+{
+	if (priv->auto_hide_page_on_stroke){
+		gnome_canvas_item_hide (priv->auto_hide_page_on_stroke);
+		priv->auto_hide_page_on_stroke = NULL;
+	}
+}
+
 static int
 gpp_newpath (GnomePrintContext *pc)
 {
@@ -268,9 +286,11 @@ gpp_stroke (GnomePrintContext *pc)
 	GnomeCanvasItem *item;
 	GraphicContext *g = gc (priv);
 	
-	g_return_val_if_fail (g->bpath != NULL, -1);
-
+	if (g->bpath == NULL)
+		return 0;
+	
 	close_path (g->bpath);
+	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		GNOME_CANVAS_GROUP (priv->page),
 		gnome_canvas_bpath_get_type (),
@@ -296,6 +316,7 @@ gpp_strokepath (GnomePrintContext *pc)
 
 	close_path (gc (priv)->bpath);
 	g_warning ("Strokepath is not tested");
+	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		GNOME_CANVAS_GROUP (priv->page),
 		gnome_canvas_bpath_get_type (),
@@ -319,6 +340,7 @@ gpp_fill (GnomePrintContext *pc)
 	g_return_val_if_fail (gc (priv)->bpath != NULL, -1);
 
 	close_path (gc (priv)->bpath);
+	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		GNOME_CANVAS_GROUP (priv->page),
 		gnome_canvas_bpath_get_type (),
@@ -357,8 +379,6 @@ gpp_setlinewidth (GnomePrintContext *pc, double width)
 static int
 gpp_setmiterlimit (GnomePrintContext *pc, double limit)
 {
-	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
-
 	g_warning ("WOOOOO  What does SetMiterLimit do?");
 	return -1;
 }
@@ -567,6 +587,7 @@ gpp_image (GnomePrintContext *pc, char *data, int width, int height, int rowstri
 	} else
 		return -1;
 
+	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		GNOME_CANVAS_GROUP (priv->page),
 		gnome_canvas_image_get_type (),
@@ -702,6 +723,7 @@ gpp_show (GnomePrintContext *pc, char const *text)
 	x = g->bpath->bpath [0].x3;
 	y = g->bpath->bpath [0].y3;
 
+	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
 		GNOME_CANVAS_GROUP (priv->page),
 		gnome_canvas_hacktext_get_type (),
@@ -720,6 +742,8 @@ gpp_show (GnomePrintContext *pc, char const *text)
 	transform [1] = -transform [1];
 	transform [2] = -transform [2];
 	gnome_canvas_item_affine_absolute (item, transform);
+
+	priv->current_page++;
 	
 	gc_clear_bpath (gc (priv));
 	return 0;
@@ -945,7 +969,8 @@ gnome_print_preview_get_type (void)
 static GtkObjectClass *pjob_parent_class;
 
 struct _GnomePrintPreviewJobPrivate {
-	GArray *pages;
+	GArray          *pages;
+	int              last_page_shown;
 };
 
 static void
@@ -967,6 +992,7 @@ pjob_init (GtkObject *object)
 	GnomePrintPreviewJob *pjob = GNOME_PRINT_PREVIEW_JOB (object);
 	
 	pjob->priv = g_new0 (GnomePrintPreviewJobPrivate, 1);
+	pjob->priv->last_page_shown = -1;
 }
 
 static void
@@ -1023,11 +1049,12 @@ gnome_print_preview_job_construct (GnomePrintPreviewJob *pjob, GnomePrintPreview
 	g_return_if_fail (pjob != NULL);
 	g_return_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob));
 
+	lazy_showpage_check (preview->priv);
 	gtk_object_ref (GTK_OBJECT (preview->canvas));
 	pjob->canvas = preview->canvas;
-
 	size = preview->priv->pages->len;
 	pjob->priv->pages = g_array_new (size, 0, sizeof (GnomeCanvasItem *));
+
 	for (i = 0; i < size; i++){
 		GnomeCanvasItem *item;
 		
@@ -1065,20 +1092,52 @@ gnome_print_preview_get_job (GnomePrintPreview *preview)
  * gnome_print_preview_job_page_visible:
  * @pjob: #GnomePrintPreview object
  * @page: page to display, or -1 to not display any page.
- * @visible: Whether to display the page or not.
  *
- * Displays the page @page.  If @page is -1, it does not display any page
+ * Displays the page @page.  
  */
 void
-gnome_print_preview_job_page_visible (GnomePrintPreviewJob *pjob, int page, gboolean visible)
+gnome_print_preview_job_page_show (GnomePrintPreviewJob *pjob, int page)
 {
+	GnomeCanvasItem *item;
+	
 	g_return_if_fail (pjob != NULL);
 	g_return_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob));
-	g_return_if_fail (page < 0);
+	g_return_if_fail (page >= 0);
 
-	g_error ("implement me");
+	if (page < 0)
+		return;
+
+	if (page >= pjob->priv->pages->len)
+		return;
+
+	if (pjob->priv->last_page_shown != -1){
+		GnomeCanvasItem *item;
+		
+		item = g_array_index (pjob->priv->pages, GnomeCanvasItem *, pjob->priv->last_page_shown);
+		gnome_canvas_item_hide (item);
+	}
+	
+	item = g_array_index (pjob->priv->pages, GnomeCanvasItem *, page);
+	gnome_canvas_item_show (item);
+
+	pjob->priv->last_page_shown = page;
 }
 
+int
+gnome_print_preview_job_num_pages (GnomePrintPreviewJob *pjob)
+{
+	g_return_val_if_fail (pjob != NULL, 0);
+	g_return_val_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob), 0);
 
+	return pjob->priv->pages->len;
+}
 
+int
+gnome_print_preview_job_current_page (GnomePrintPreviewJob *pjob)
+{
+	g_return_val_if_fail (pjob != NULL, 0);
+	g_return_val_if_fail (GNOME_IS_PRINT_PREVIEW_JOB (pjob), 0);
+
+	return pjob->priv->last_page_shown;
+}
 
