@@ -44,14 +44,14 @@ gnome_print_ps_get_type (void)
 
 /* The implementations of the PostScript paint methods, autogenned */
 
-int
+static int
 gnome_print_ps_newpath (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "newpath\n");
 }
 
-int
+static int
 gnome_print_ps_moveto (GnomePrintContext *pc, double x, double y)
 {
   return gnome_print_context_fprintf (pc,
@@ -60,7 +60,7 @@ gnome_print_ps_moveto (GnomePrintContext *pc, double x, double y)
                                       y);
 }
 
-int
+static int
 gnome_print_ps_lineto (GnomePrintContext *pc, double x, double y)
 {
   return gnome_print_context_fprintf (pc,
@@ -69,8 +69,11 @@ gnome_print_ps_lineto (GnomePrintContext *pc, double x, double y)
                                       y);
 }
 
-int
-gnome_print_ps_curveto (GnomePrintContext *pc, double x1, double y1, double x2, double y2, double x3, double y3)
+static int
+gnome_print_ps_curveto (GnomePrintContext *pc,
+			double x1, double y1,
+			double x2, double y2,
+			double x3, double y3)
 {
   return gnome_print_context_fprintf (pc,
                                       "%g %g %g %g %g %g curveto\n",
@@ -82,24 +85,31 @@ gnome_print_ps_curveto (GnomePrintContext *pc, double x1, double y1, double x2,
                                       y3);
 }
 
-int
+static int
 gnome_print_ps_closepath (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "closepath\n");
 }
 
-int
+static int
 gnome_print_ps_setrgbcolor (GnomePrintContext *pc,
 			    double r, double g, double b)
 {
   GnomePrintPs *ps = GNOME_PRINT_PS (pc);
 
+  /* I think there's a problem:
+   * gsave, setcolor, grestore means a setrgbcolor is required;
+   * ps->r, etc. are the "last set" color, not the "current color"
+   * so you need a color stack to do this optimization.
+   */
+#if 0
   /* if the current color is the color the user wants to set, noop */
   if (ps->r == r &&
       ps->g == g &&
       ps->b == b)
     return 0;
+#endif
 
   ps->r = r; ps->g = g; ps->b = b;
 
@@ -110,21 +120,21 @@ gnome_print_ps_setrgbcolor (GnomePrintContext *pc,
                                       b);
 }
 
-int
+static int
 gnome_print_ps_fill (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "fill\n");
 }
 
-int
+static int
 gnome_print_ps_eofill (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "eofill\n");
 }
 
-int
+static int
 gnome_print_ps_setlinewidth (GnomePrintContext *pc, double width)
 {
   return gnome_print_context_fprintf (pc,
@@ -132,7 +142,7 @@ gnome_print_ps_setlinewidth (GnomePrintContext *pc, double width)
                                       width);
 }
 
-int
+static int
 gnome_print_ps_setmiterlimit (GnomePrintContext *pc, double limit)
 {
   return gnome_print_context_fprintf (pc,
@@ -140,7 +150,7 @@ gnome_print_ps_setmiterlimit (GnomePrintContext *pc, double limit)
                                       limit);
 }
 
-int
+static int
 gnome_print_ps_setlinejoin (GnomePrintContext *pc, int jointype)
 {
   return gnome_print_context_fprintf (pc,
@@ -148,7 +158,7 @@ gnome_print_ps_setlinejoin (GnomePrintContext *pc, int jointype)
                                       jointype);
 }
 
-int
+static int
 gnome_print_ps_setlinecap (GnomePrintContext *pc, int captype)
 {
   return gnome_print_context_fprintf (pc,
@@ -156,7 +166,7 @@ gnome_print_ps_setlinecap (GnomePrintContext *pc, int captype)
                                       captype);
 }
 
-int
+static int
 gnome_print_ps_setdash (GnomePrintContext *pc, int n_values, double *values, double offset)
 {
   return gnome_print_context_fprintf (pc,
@@ -166,14 +176,14 @@ gnome_print_ps_setdash (GnomePrintContext *pc, int n_values, double *values, dou
                                       offset);
 }
 
-int
+static int
 gnome_print_ps_strokepath (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "strokepath\n");
 }
 
-int
+static int
 gnome_print_ps_stroke (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
@@ -238,7 +248,7 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
 }
 
 /* todo: just make this call the _raw variant on the unsized font */
-int
+static int
 gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 {
   GnomePrintPs *ps;
@@ -281,9 +291,12 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 	}
     }
 
+  /* This doesn't consider gsave/grestore... */
+#if 0
   if (ps->current_font && strcmp (ps->current_font, fontname) == 0 &&
       ps->current_font_size == font->size)
     return 0; /* this font is already set */
+#endif
 
   ps->current_font = fontname;
   ps->current_font_size = font->size;
@@ -298,8 +311,8 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 
 }
 
-int
-gnome_print_ps_show (GnomePrintContext *pc, char *text)
+static int
+gnome_print_ps_show (GnomePrintContext *pc, char const *text)
 {
   int i;
 
@@ -323,7 +336,7 @@ gnome_print_ps_show (GnomePrintContext *pc, char *text)
   return gnome_print_context_fprintf (pc, ") show\n");
 }
 
-int
+static int
 gnome_print_ps_concat (GnomePrintContext *pc, double matrix[6])
 {
   char str[128];
@@ -333,7 +346,7 @@ gnome_print_ps_concat (GnomePrintContext *pc, double matrix[6])
                                       "%s\n", str);
 }
 
-int
+static int
 gnome_print_ps_setmatrix (GnomePrintContext *pc, double matrix[6])
 {
   return gnome_print_context_fprintf (pc,
@@ -346,35 +359,35 @@ gnome_print_ps_setmatrix (GnomePrintContext *pc, double matrix[6])
                                       matrix[5]);
 }
 
-int
+static int
 gnome_print_ps_gsave (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "gsave\n");
 }
 
-int
+static int
 gnome_print_ps_grestore (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "grestore\n");
 }
 
-int
+static int
 gnome_print_ps_clip (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "clip\n");
 }
 
-int
+static int
 gnome_print_ps_eoclip (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
                                       "eoclip\n");
 }
 
-static int
+static static int
 gnome_print_ps_image (GnomePrintContext *pc, char *data, int width, int height, int rowstride, int bytes_per_pixel)
 {
   int status;
@@ -442,19 +455,19 @@ gnome_print_ps_image (GnomePrintContext *pc, char *data, int width, int height,
   return 0;
 }
 
-int
+static int
 gnome_print_ps_grayimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
 {
   return  gnome_print_ps_image (pc, data, width, height, rowstride, 1);
 }
 
-int
+static int
 gnome_print_ps_rgbimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
 {
   return gnome_print_ps_image (pc, data, width, height, rowstride, 3);
 }
 
-int
+static int
 gnome_print_ps_textline (GnomePrintContext *pc, GnomeTextLine *line)
 {
   int i;
@@ -546,7 +559,7 @@ gnome_print_ps_textline (GnomePrintContext *pc, GnomeTextLine *line)
   return 0;
 }
 
-int
+static int
 gnome_print_ps_showpage (GnomePrintContext *pc)
 {
   return gnome_print_context_fprintf (pc,
@@ -669,6 +682,14 @@ gnome_print_ps_init (GnomePrintPs *ps)
   ps->current_font_size = 0;
 }
 
+/**
+ * gnome_print_ps_new:
+ * @printer: Where do we print
+ *
+ * Creates a new Postscript printing context
+ *
+ * Returns: a new GnomePrintPs object in which you can issue GnomePrint commands.
+ */
 GnomePrintPs *
 gnome_print_ps_new (GnomePrinter *printer)
 {
