@@ -94,15 +94,8 @@ gnome_print_context_init (GnomePrintContext *pc)
   pc->f = NULL;
 }
 
-/* This dispatch is by cases rather than being object oriented. It may
-   be desirable to make it more OO. Basically, the way that would be
-   done would be to have a gnome_printer_make_new_context () method
-   on GnomePrinter objects.
-
-   However, this will do for now, and saves making extra classes.
-*/
 GnomePrintContext *
-gnome_print_context_new (GnomePrinter *printer, const char *paper_size)
+gnome_print_context_new_with_paper_size (GnomePrinter *printer, const char *paper_size)
 {
 	if (strcmp (printer->driver, "gnome-print-ps") == 0)
 		return GNOME_PRINT_CONTEXT (gnome_print_ps_new (printer));
@@ -113,6 +106,19 @@ gnome_print_context_new (GnomePrinter *printer, const char *paper_size)
 	return NULL;
 }
 
+/* This dispatch is by cases rather than being object oriented. It may
+   be desirable to make it more OO. Basically, the way that would be
+   done would be to have a gnome_printer_make_new_context () method
+   on GnomePrinter objects.
+
+   However, this will do for now, and saves making extra classes.
+*/
+GnomePrintContext *
+gnome_print_context_new (GnomePrinter *printer)
+{
+	return gnome_print_context_new_with_paper_size (printer, "US-Letter");
+}
+
 static void
 gnome_print_context_finalize (GtkObject *object)
 {
